function EKF2D(f)
% usage:
%        EKF2D(f)
% f is the figure which would be displayed.


% use this command for a random run.
RandStream.setDefaultStream(RandStream('mt19937ar','seed',sum(100*clock)));

% use this command for repeatability
%RandStream.setDefaultStream(RandStream('mt19937ar','seed',sum(100*32564)));

figure(f);clf;

global piconst;
piconst=pi/180.0;

% Sampling rate
dt=1;

% The linear (v) and angular (w) velocity noisy
sigma_v=0.1;
sigma_w=0.01;

% The sensor uncertainty
% Not used here. Just propagation
%global sigma_z;
%sigma_z=diag([1 2*pi/180]);

% The Initial Orientation of the robot
thetaInit=-30;

% Number of landmarks.
% No landmarks, no updates.
% Nl=50; 

% Real robot pose
%xr=[(rand(2,1)-0.5)*1000,thetaInit*pi/180];
%xr=[(rand(2,1)-0.5)*1000,thetaInit*pi/180];
xr=[0, 0, thetaInit*pi/180]';

% Estimated State
x=zeros(3,1);
x=xr;

% Estimated Covariance.
P=eye(3,3)*0.20;
P(3,3)=0.01;
% Use this for no initial uncertainty
%P=zeros(3,3);

% Landmark Locations (plotted in green)
%Map=(rand(2,Nl)-0.5)*1000;
%plot(Map(1,:),Map(2,:),'g+'); hold on;
%drawnow;

% Angular velocity
w=0; % rad/sec
% Linear velocity
V=9; % m/sec

% Propagation noise covariance
Q=[sigma_v^2 0
   0 sigma_w^2];


for k=1:1:200
    if(mod(k,10)==0) k
        w=(rand(1,1)-0.5)*(20*pi/180);
    end
    % Moving the real robot.
    e_v=randn(1,1)*sigma_v;
    e_w=randn(1,1)*sigma_w;
    xr(1,1)=xr(1,1)+(V+e_v).*dt.*cos(xr(3,1));
    xr(2,1)=xr(2,1)+(V+e_v).*dt.*sin(xr(3,1));
    xr(3,1)=xr(3,1)+(w+e_w).*dt;
    xr(3,1)=AngleWrap(xr(3,1));
    % plot the robots trajectory as red dots.
    plot(xr(1,1),xr(2,1),'r.'); hold on;
    drawnow;
    
    % propagate the state estimate x and the covariance P
    [x,P]=Propagate(V,w,dt,x,P,Q);
    
    % Every 5 steps plot the estimate and the covariance ellipse. 
    if mod(k,5)==0
        plot(x(1,1),x(2,1),'b.'); hold on;
        ellipseC(x(1:2,1)',P(1:2,1:2));
        drawnow;
    end
        
    axis equal;    
end;
