function Y = ellipseGeneration(center, halfaxis, angle)
% Y = ellipseGeneration(center, axis, angle) generates 100 points on an ellipse
%
%       center   = [xc yc] is the desired center for the ellipse
%       halfaxis = [dx dy] is the semi-major and semiminor axes of the ellipse
%       angle      is the angle that the major axis of the ellipse is 
%                  rotated from the horizontal

%       Statistics 3013 - Michael Anderson - September 2001
%       UTSA Department of Management Science and Statistics


t       = linspace(0,2*pi,100);
xt      = halfaxis(1)*cos(t);
yt      = halfaxis(2)*sin(t);

if (angle == 0)
        xt = xt + center(1);
        yt = yt + center(2);
        Y = [xt; yt];
else
        R = [cos(angle) sin(angle); -sin(angle) cos(angle)];
        X = [xt; yt];
        Y = X'*R';
        [rr,cc] = size(Y);
        J = ones(rr,1);
        Y = Y + (J*center);
        Y = Y';
end;
